﻿AutoCombatLog = LibStub("AceAddon-3.0"):NewAddon("AutoCombatLog", "AceConsole-3.0", "AceEvent-3.0")

local db = nil

local options = { 
    name = "AutoCombatLog",
    handler = AutoCombatLog,
    type = "group",
    args = {
        raidEnabled = {
            type = "toggle",
            name = "Enable for raids",
            desc = "Enable automatic logging whenever you enter a raid instance.",
			get = function() return db.raidEnabled end,
			set = function(info, value) db.raidEnabled = value end,
			order = 0,
        },
		partyEnabled = {
			type = "toggle",
			name = "Enable for party",
			desc = "Enable automatic logging whenever you enter a 5-man instance.",
			get = function() return db.partyEnabled end,
			set = function(info, value) db.partyEnabled = value end,
			order = 1,
		},
    },
}

local defaults = {
	profile = {
		raidEnabled = true,
		partyEnabled = false,
	},
}

function AutoCombatLog:OnInitialize()
	self.db = LibStub("AceDB-3.0"):New("AutoCombatLogDB", defaults, "Default")
	db = self.db.profile
    LibStub("AceConfig-3.0"):RegisterOptionsTable("AutoCombatLog", options)
    self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("AutoCombatLog", "AutoCombatLog")
    self:RegisterChatCommand("autocombatlog", "ChatCommand")
    self:RegisterChatCommand("acl", "ChatCommand")
end

function AutoCombatLog:OnEnable()
    self:RegisterEvent("PLAYER_ENTERING_WORLD")
	self:RegisterEvent("PLAYER_LOGOUT")
end

function AutoCombatLog:OnDisable()
    self:UnregisterAllEvents()
end

function AutoCombatLog:PLAYER_LOGOUT()
	LoggingCombat(0)
end

function AutoCombatLog:PLAYER_ENTERING_WORLD()
	inInstance, instanceType = IsInInstance()
    if(instanceType == "raid" and db.raidEnabled) then
		LoggingCombat(1)
		AutoCombatLog:Print("Combat logging has been enabled.")
	elseif(instanceType == "party" and db.partyEnabled) then
		LoggingCombat(1)
		AutoCombatLog:Print("Combat logging has been enabled.")
	elseif(instanceType == "none" and LoggingCombat()) then
		LoggingCombat(0)
		AutoCombatLog:Print("Combat logging has been disabled.")
    end
end

function AutoCombatLog:ChatCommand(input)
   if not input or input:trim() == "" then
		InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
   else
		LibStub("AceConfigCmd-3.0").HandleCommand(AutoCombatLog, "acl", "AutoCombatLog", input)
   end
end